##  Understanding Interface Arrows in Data Flow Diagrams
In data flow diagrams, arrows between applications represent interfaces. The arrow style and color indicate the lifecycle phase of the interface:
Style | Color | Lifecycle Phase
---|---|---
Dashed | Light gray | Planned
Dashed | Gray | Phase-in
Solid | Blue | Active
Solid | Yellow | Phase-out
Solid | Red | End of life
Solid | Black | No lifecycle assigned


The direction of the arrowhead indicates the interface data flow direction (incoming, outgoing, or bidirectional). The color of interface lines is tied to the lifecycle phase and cannot be manually changed.
